@@ -6,5 +6,5 @@ Supported CAPTCHAs
 
 # pylint: disable=unused-import,import-error
 from ._captcha import ImageCaptcha, TextCaptcha, RecaptchaV2, RecaptchaV3
-from ._captcha import HCaptcha, FunCaptcha, KeyCaptcha, GeeTest, Capy
+from ._captcha import HCaptcha, FunCaptcha, KeyCaptcha, GeeTest, Capy, TikTokCaptcha
 from ._captcha import CaptchaType
